package sun.security.krb5.internal;

import java.net.PortUnreachableException;
import java.io.IOException;
import java.net.SocketException;
import java.net.UnknownHostException;
import java.net.DatagramPacket;
import java.net.DatagramSocket;
import java.net.InetAddress;

class UDPClient extends NetClient
{
    InetAddress iaddr;
    int iport;
    int bufSize;
    DatagramSocket dgSocket;
    DatagramPacket dgPacketIn;
    
    UDPClient(String host, int iport, int soTimeout) throws UnknownHostException, SocketException {
        this.bufSize = 65507;
        this.iaddr = InetAddress.getByName(host);
        this.iport = iport;
        (this.dgSocket = new DatagramSocket()).setSoTimeout(soTimeout);
        this.dgSocket.connect(this.iaddr, this.iport);
    }
    
    @Override
    public void send(byte[] buf) throws IOException {
        this.dgSocket.send(new DatagramPacket(buf, buf.length, this.iaddr, this.iport));
    }
    
    @Override
    public byte[] receive() throws IOException {
        byte[] buf = new byte[this.bufSize];
        this.dgPacketIn = new DatagramPacket(buf, buf.length);
        try {
            this.dgSocket.receive(this.dgPacketIn);
        }
        catch (SocketException ex) {
            if ((ex instanceof PortUnreachableException)) {
                throw ex;
            }
            this.dgSocket.receive(this.dgPacketIn);
        }
        byte[] array = new byte[this.dgPacketIn.getLength()];
        System.arraycopy(this.dgPacketIn.getData(), 0, array, 0, this.dgPacketIn.getLength());
        return array;
    }
    
    @Override
    public void close() {
        this.dgSocket.close();
    }
}
